@@ -25,8 +25,8 @@ DEBUG_BUILD=0
 ASAN_BUILD=0
 DEPLOY=1
 ENABLE_FREI0R=1
-FREI0R_HEAD=0
-FREI0R_REVISION="36e7da5d9e1f8b8cac9e97e204db1c5834fee580"
+FREI0R_HEAD=1
+FREI0R_REVISION=
 SUBDIRS=
 ENABLE_MOVIT=1
 MOVIT_HEAD=0
@@ -42,7 +42,7 @@ SHOTCUT_REVISION=
 SHOTCUT_VERSION=$(date '+%y.%m.%d')
 ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=0
-BIGSH0T_REVISION="8fe56f6d4e"
+BIGSH0T_REVISION="710e734512b8975722f0c41f793f28c51a3d2b88"
 DAV1D_HEAD=0
 DAV1D_REVISION="1.5.0"
 AOM_HEAD=0
@@ -65,8 +65,8 @@ LADSPA_HEAD=0
 LADSPA_REVISION="origin/shotcut"
 MLT_DISABLE_SOX=0
 ENABLE_WHISPERCPP=1
-WHISPERCPP_HEAD=1
-WHISPERCPP_REVISION=
+WHISPERCPP_HEAD=0
+WHISPERCPP_REVISION="v1.7.4"
 NV_CODEC_REVISION="sdk/12.0"
 
 PYTHON_VERSION=$(python3 --version | awk '{split($2, parts, "."); print parts[1] "." parts[2]}')
@@ -444,7 +444,7 @@ function set_globals {
 #  REPOLOCS[8]="https://bitbucket.org/dandennedy/bigsh0t.git"
   REPOLOCS[8]="https://bitbucket.org/leo_sutic/bigsh0t.git"
   REPOLOCS[9]="https://github.com/ggerganov/whisper.cpp.git"
-  REPOLOCS[10]="https://code.videolan.org/videolan/dav1d.git"
+  REPOLOCS[10]="https://github.com/videolan/dav1d.git"
   REPOLOCS[11]="https://aomedia.googlesource.com/aom"
   REPOLOCS[12]="https://github.com/Netflix/vmaf.git"
   REPOLOCS[13]="https://gitlab.com/ddennedy/glaxnimate.git"
@@ -505,6 +505,9 @@ function set_globals {
     REVISIONS[8]="$BIGSH0T_REVISION"
   fi
   REVISIONS[9]=""
+  if test 0 = "$WHISPERCPP_HEAD" -a "$WHISPERCPP_REVISION" ; then
+    REVISIONS[9]="$WHISPERCPP_REVISION"
+  fi
   REVISIONS[10]=""
   if test 0 = "$DAV1D_HEAD" -a "$DAV1D_REVISION" ; then
     REVISIONS[10]="$DAV1D_REVISION"
