@@ -27,8 +27,8 @@ DEBUG_BUILD=0
 ASAN_BUILD=0
 CREATE_STARTUP_SCRIPT=1
 ENABLE_FREI0R=1
-FREI0R_HEAD=0
-FREI0R_REVISION="36e7da5d9e1f8b8cac9e97e204db1c5834fee580"
+FREI0R_HEAD=1
+FREI0R_REVISION=
 ENABLE_MOVIT=1
 SUBDIRS=
 MOVIT_HEAD=0
@@ -76,7 +76,7 @@ RUBBERBAND_HEAD=0
 RUBBERBAND_REVISION="v3.3.0"
 ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=0
-BIGSH0T_REVISION="8fe56f6d4e"
+BIGSH0T_REVISION="2.7"
 ENABLE_ZIMG=1
 ZIMG_HEAD=0
 ZIMG_REVISION="51c3c7f750c2af61955377faad56e3ba1b03589f"
@@ -85,7 +85,7 @@ DAV1D_REVISION="1.5.0"
 AOM_HEAD=0
 AOM_REVISION="v3.11.0"
 SVTAV1_HEAD=0
-SVTAV1_REVISION="v2.1.0"
+SVTAV1_REVISION="v2.3.0"
 VMAF_HEAD=0
 VMAF_REVISION="v3.0.0"
 ENABLE_GLAXNIMATE=1
@@ -102,8 +102,8 @@ ENABLE_LIBSPATIALAUDIO=1
 LIBSPATIALAUDIO_HEAD=1
 LIBSPATIALAUDIO_REVISION=
 ENABLE_WHISPERCPP=1
-WHISPERCPP_HEAD=1
-WHISPERCPP_REVISION=
+WHISPERCPP_HEAD=0
+WHISPERCPP_REVISION="v1.7.4"
 NV_CODEC_REVISION="sdk/12.0"
 MFX_DISPATCH_REVISION="1.25"
 
@@ -712,6 +712,10 @@ function set_globals {
   if test 0 = "$SVTAV1_HEAD" -a "$SVTAV1_REVISION" ; then
     REVISIONS[29]="$SVTAV1_REVISION"
   fi
+  REVISIONS[30]=""
+  if test 0 = "$WHISPERCPP_HEAD" -a "$WHISPERCPP_REVISION" ; then
+    REVISIONS[30]="$WHISPERCPP_REVISION"
+  fi
 
   # Figure out the number of cores in the system. Used both by make and startup script
   if test "$TARGET_OS" = "Darwin"; then
@@ -1902,7 +1906,7 @@ function deploy_mac
 
   # whisper.cpp
   cmd cp -p "$FINAL_INSTALL_DIR"/lib/libwhisper.1.dylib Frameworks
-  cmd cp -p "$FINAL_INSTALL_DIR"/lib/libggml.dylib Frameworks
+  cmd cp -p "$FINAL_INSTALL_DIR"/lib/libggml*.dylib Frameworks
   fixlibs MacOS/whisper-cli
   log fixing rpath of executable "whisper-cli"
   cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/src MacOS/whisper-cli 2> /dev/null
