@@ -15,19 +15,21 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtWidgets>
-#include <QUrl>
+#include "videowidget.h"
+
+#include "Logger.h"
+#include "mainwindow.h"
+#include "qmltypes/qmlfilter.h"
+#include "qmltypes/qmlutilities.h"
+#include "settings.h"
+
+#include <Mlt.h>
 #include <QOffscreenSurface>
 #include <QOpenGLContext>
-#include <QtQml>
 #include <QQuickItem>
-#include <Mlt.h>
-#include <Logger.h>
-#include "videowidget.h"
-#include "settings.h"
-#include "qmltypes/qmlutilities.h"
-#include "qmltypes/qmlfilter.h"
-#include "mainwindow.h"
+#include <QUrl>
+#include <QtQml>
+#include <QtWidgets>
 
 using namespace Mlt;
 
@@ -43,6 +45,7 @@ VideoWidget::VideoWidget(QObject *parent)
     , m_snapToGrid(true)
     , m_scrubAudio(false)
     , m_maxTextureSize(4096)
+    , m_hideVui(false)
 {
     LOG_DEBUG() << "begin";
     setAttribute(Qt::WA_AcceptTouchEvents);
@@ -62,7 +65,10 @@ VideoWidget::VideoWidget(QObject *parent)
         m_glslManager.reset();
     }
 
-    connect(quickWindow(), &QQuickWindow::visibilityChanged, this, &VideoWidget::setBlankScene,
+    connect(quickWindow(),
+            &QQuickWindow::visibilityChanged,
+            this,
+            &VideoWidget::setBlankScene,
             Qt::QueuedConnection);
     connect(&m_refreshTimer, &QTimer::timeout, this, &VideoWidget::onRefreshTimeout);
     connect(this, &VideoWidget::rectChanged, this, &VideoWidget::zoomChanged);
@@ -85,19 +91,23 @@ void VideoWidget::initialize()
 {
     LOG_DEBUG() << "begin";
     m_frameRenderer = new FrameRenderer();
-    connect(m_frameRenderer, &FrameRenderer::frameDisplayed, this,
-            &VideoWidget::onFrameDisplayed, Qt::QueuedConnection);
-    connect(m_frameRenderer, &FrameRenderer::frameDisplayed, this,
-            &VideoWidget::frameDisplayed, Qt::QueuedConnection);
+    connect(m_frameRenderer,
+            &FrameRenderer::frameDisplayed,
+            this,
+            &VideoWidget::onFrameDisplayed,
+            Qt::QueuedConnection);
+    connect(m_frameRenderer,
+            &FrameRenderer::frameDisplayed,
+            this,
+            &VideoWidget::frameDisplayed,
+            Qt::QueuedConnection);
     connect(m_frameRenderer, SIGNAL(imageReady()), SIGNAL(imageReady()));
     m_initSem.release();
     m_isInitialized = true;
     LOG_DEBUG() << "end";
 }
 
-void VideoWidget::renderVideo()
-{
-}
+void VideoWidget::renderVideo() {}
 
 void VideoWidget::setBlankScene()
 {
@@ -147,7 +157,8 @@ void VideoWidget::onRefreshTimeout()
 void VideoWidget::mousePressEvent(QMouseEvent *event)
 {
     QQuickWidget::mousePressEvent(event);
-    if (event->isAccepted()) return;
+    if (event->isAccepted())
+        return;
     if (event->button() == Qt::LeftButton)
         m_dragStart = event->pos();
     else if (event->button() == Qt::MiddleButton)
@@ -159,7 +170,8 @@ void VideoWidget::mousePressEvent(QMouseEvent *event)
 void VideoWidget::mouseMoveEvent(QMouseEvent *event)
 {
     QQuickWidget::mouseMoveEvent(event);
-    if (event->isAccepted()) return;
+    if (event->isAccepted())
+        return;
     if (event->buttons() & Qt::MiddleButton) {
         emit offsetChanged(m_offset + m_mousePosition - event->pos());
         m_mousePosition = event->pos();
@@ -195,7 +207,8 @@ void VideoWidget::mouseMoveEvent(QMouseEvent *event)
     mimeData->setText(QString::number(MLT.producer()->get_playtime()));
     if (m_frameRenderer && m_frameRenderer->getDisplayFrame().is_valid()) {
         Mlt::Frame displayFrame(m_frameRenderer->getDisplayFrame().clone(false, true));
-        QImage displayImage = MLT.image(&displayFrame, 45 * MLT.profile().dar(), 45).scaledToHeight(45);
+        QImage displayImage
+            = MLT.image(&displayFrame, 45 * MLT.profile().dar(), 45).scaledToHeight(45);
         drag->setPixmap(QPixmap::fromImage(displayImage));
     }
     drag->setHotSpot(QPoint(0, 0));
@@ -205,7 +218,8 @@ void VideoWidget::mouseMoveEvent(QMouseEvent *event)
 void VideoWidget::keyPressEvent(QKeyEvent *event)
 {
     QQuickWidget::keyPressEvent(event);
-    if (event->isAccepted()) return;
+    if (event->isAccepted())
+        return;
     MAIN.keyPressEvent(event);
 }
 
@@ -256,7 +270,9 @@ static void onThreadCreate(mlt_properties owner, VideoWidget *self, mlt_event_da
     Q_UNUSED(owner)
     auto threadData = (mlt_event_data_thread *) Mlt::EventData(data).to_object();
     if (threadData) {
-        self->createThread((RenderThread **) threadData->thread, threadData->function, threadData->data);
+        self->createThread((RenderThread **) threadData->thread,
+                           threadData->function,
+                           threadData->data);
     }
 }
 
@@ -301,7 +317,7 @@ void VideoWidget::stopGlsl()
     //Technically, this should be the correct thing to do, but it appears
     //some changes in the 15.01 and 15.03 releases have created regression
     //with respect to restarting the consumer in GPU mode.
-//    m_glslManager->fire_event("close glsl");
+    //    m_glslManager->fire_event("close glsl");
 }
 
 static void onThreadStopped(mlt_properties owner, VideoWidget *self)
@@ -328,7 +344,8 @@ int VideoWidget::reconfigure(bool isMulti)
         if (isMulti)
             m_consumer.reset(new Mlt::FilteredConsumer(previewProfile(), "multi"));
         else
-            m_consumer.reset(new Mlt::FilteredConsumer(previewProfile(), serviceName.toLatin1().constData()));
+            m_consumer.reset(
+                new Mlt::FilteredConsumer(previewProfile(), serviceName.toLatin1().constData()));
 
         m_threadStartEvent.reset();
         m_threadStopEvent.reset();
@@ -341,7 +358,8 @@ int VideoWidget::reconfigure(bool isMulti)
         // Make an event handler for when a frame's image should be displayed
         m_consumer->listen("consumer-frame-show", this, (mlt_listener) on_frame_show);
         m_consumer->set("real_time", MLT.realTime());
-        m_consumer->set("mlt_image_format", serviceName.startsWith("decklink") ? "yuv422p" : "yuv420p");
+        m_consumer->set("mlt_image_format",
+                        serviceName.startsWith("decklink") ? "yuv422p" : "yuv420p");
         m_consumer->set("channels", property("audio_channels").toInt());
         if (property("audio_channels").toInt() == 4) {
             m_consumer->set("channel_layout", "quad");
@@ -392,16 +410,19 @@ int VideoWidget::reconfigure(bool isMulti)
         }
         if (m_glslManager) {
             if (!m_threadCreateEvent)
-                m_threadCreateEvent.reset(m_consumer->listen("consumer-thread-create", this,
+                m_threadCreateEvent.reset(m_consumer->listen("consumer-thread-create",
+                                                             this,
                                                              (mlt_listener) onThreadCreate));
             if (!m_threadJoinEvent)
-                m_threadJoinEvent.reset(m_consumer->listen("consumer-thread-join", this,
-                                                           (mlt_listener) onThreadJoin));
+                m_threadJoinEvent.reset(
+                    m_consumer->listen("consumer-thread-join", this, (mlt_listener) onThreadJoin));
             if (!m_threadStartEvent)
-                m_threadStartEvent.reset(m_consumer->listen("consumer-thread-started", this,
+                m_threadStartEvent.reset(m_consumer->listen("consumer-thread-started",
+                                                            this,
                                                             (mlt_listener) onThreadStarted));
             if (!m_threadStopEvent)
-                m_threadStopEvent.reset(m_consumer->listen("consumer-thread-stopped", this,
+                m_threadStopEvent.reset(m_consumer->listen("consumer-thread-stopped",
+                                                           this,
                                                            (mlt_listener) onThreadStopped));
         } else {
             emit started();
@@ -427,7 +448,7 @@ QPoint VideoWidget::offset() const
     if (m_zoom == 0.0) {
         return QPoint(0, 0);
     } else {
-        return QPoint(m_offset.x() - (MLT.profile().width()  * m_zoom -  width()) / 2,
+        return QPoint(m_offset.x() - (MLT.profile().width() * m_zoom - width()) / 2,
                       m_offset.y() - (MLT.profile().height() * m_zoom - height()) / 2);
     }
 }
@@ -466,12 +487,18 @@ void VideoWidget::requestImage() const
     m_frameRenderer->requestImage();
 }
 
+void VideoWidget::toggleVuiDisplay()
+{
+    m_hideVui = !m_hideVui;
+    refreshConsumer();
+}
+
 void VideoWidget::onFrameDisplayed(const SharedFrame &frame)
 {
     m_mutex.lock();
     m_sharedFrame = frame;
     m_mutex.unlock();
-    bool isVui = frame.get_int(kShotcutVuiMetaProperty);
+    bool isVui = frame.get_int(kShotcutVuiMetaProperty) && !m_hideVui;
     if (!isVui && source() != QmlUtilities::blankVui()) {
         m_savedQmlSource = source();
         setSource(QmlUtilities::blankVui());
@@ -513,8 +540,9 @@ void VideoWidget::setOffsetY(int y)
 
 void VideoWidget::setCurrentFilter(QmlFilter *filter, QmlMetadata *meta)
 {
+    m_hideVui = false;
     if (meta && meta->type() == QmlMetadata::Filter
-            && QFile::exists(meta->vuiFilePath().toLocalFile())) {
+        && QFile::exists(meta->vuiFilePath().toLocalFile())) {
         filter->producer().set(kShotcutVuiMetaProperty, 1);
         rootContext()->setContextProperty("filter", filter);
         setSource(meta->vuiFilePath());
@@ -536,8 +564,11 @@ void VideoWidget::on_frame_show(mlt_consumer, VideoWidget *widget, mlt_event_dat
     auto frame = Mlt::EventData(data).to_frame();
     if (frame.is_valid() && frame.get_int("rendered")) {
         int timeout = (widget->consumer()->get_int("real_time") > 0) ? 0 : 1000;
-        if (widget->m_frameRenderer && widget->m_frameRenderer->semaphore()->tryAcquire(1, timeout)) {
-            QMetaObject::invokeMethod(widget->m_frameRenderer, "showFrame", Qt::QueuedConnection,
+        if (widget->m_frameRenderer
+            && widget->m_frameRenderer->semaphore()->tryAcquire(1, timeout)) {
+            QMetaObject::invokeMethod(widget->m_frameRenderer,
+                                      "showFrame",
+                                      Qt::QueuedConnection,
                                       Q_ARG(Mlt::Frame, frame));
         } else if (!Settings.playerRealtime()) {
             LOG_WARNING() << "VideoWidget dropped frame" << frame.get_position();
@@ -550,7 +581,7 @@ RenderThread::RenderThread(thread_function_t function, void *data)
     , m_function{function}
     , m_data{data}
     , m_context{new QOpenGLContext}
-, m_surface{new QOffscreenSurface}
+    , m_surface{new QOffscreenSurface}
 {
     QSurfaceFormat format;
     format.setProfile(QSurfaceFormat::CoreProfile);
@@ -588,9 +619,7 @@ FrameRenderer::FrameRenderer()
     start();
 }
 
-FrameRenderer::~FrameRenderer()
-{
-}
+FrameRenderer::~FrameRenderer() {}
 
 void FrameRenderer::showFrame(Mlt::Frame frame)
 {
