@@ -17,27 +17,29 @@
 
 #include "imageproducerwidget.h"
 #include "ui_imageproducerwidget.h"
-#include "settings.h"
-#include "mainwindow.h"
-#include "shotcut_mlt_properties.h"
-#include "util.h"
+
+#include "Logger.h"
 #include "dialogs/filedatedialog.h"
+#include "mainwindow.h"
 #include "proxymanager.h"
 #include "qmltypes/qmlapplication.h"
-#include <Logger.h>
-#include <QFileInfo>
-#include <QDir>
-#include <QMenu>
+#include "settings.h"
+#include "shotcut_mlt_properties.h"
+#include "util.h"
+
 #include <QClipboard>
+#include <QDir>
+#include <QFileInfo>
+#include <QMenu>
 #include <QMessageBox>
 
 // This legacy property is only used in this widget.
 #define kShotcutResourceProperty "shotcut_resource"
 
-ImageProducerWidget::ImageProducerWidget(QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::ImageProducerWidget),
-    m_defaultDuration(-1)
+ImageProducerWidget::ImageProducerWidget(QWidget *parent)
+    : QWidget(parent)
+    , ui(new Ui::ImageProducerWidget)
+    , m_defaultDuration(-1)
 {
     ui->setupUi(this);
     Util::setColorsToHighlight(ui->filenameLabel, QPalette::Base);
@@ -84,15 +86,17 @@ void ImageProducerWidget::setProducer(Mlt::Producer *p)
         caption = name;
         m_producer->set(kShotcutCaptionProperty, caption.toUtf8().constData());
     }
-    ui->filenameLabel->setText(ui->filenameLabel->fontMetrics().elidedText(caption, Qt::ElideLeft,
-                                                                           width() - 30));
+    ui->filenameLabel->setText(
+        ui->filenameLabel->fontMetrics().elidedText(caption, Qt::ElideLeft, width() - 30));
     updateDuration();
     resource = QDir::toNativeSeparators(resource);
     ui->filenameLabel->setToolTip(resource);
-    bool isProxy = m_producer->get_int(kIsProxyProperty) && m_producer->get(kOriginalResourceProperty);
-    ui->resolutionLabel->setText(QStringLiteral("%1x%2 %3").arg(p->get("meta.media.width")).arg(
-                                     p->get("meta.media.height"))
-                                 .arg(isProxy ? tr("(PROXY)") : ""));
+    bool isProxy = m_producer->get_int(kIsProxyProperty)
+                   && m_producer->get(kOriginalResourceProperty);
+    ui->resolutionLabel->setText(QStringLiteral("%1x%2 %3")
+                                     .arg(p->get("meta.media.width"))
+                                     .arg(p->get("meta.media.height"))
+                                     .arg(isProxy ? tr("(PROXY)") : ""));
     ui->aspectNumSpinBox->blockSignals(true);
     if (p->get(kAspectRatioNumerator) && p->get(kAspectRatioDenominator)) {
         ui->aspectNumSpinBox->setValue(p->get_int(kAspectRatioNumerator));
@@ -122,8 +126,8 @@ void ImageProducerWidget::setProducer(Mlt::Producer *p)
 void ImageProducerWidget::updateDuration()
 {
     if (m_producer->get(kFilterOutProperty))
-        ui->durationSpinBox->setValue(m_producer->get_int(kFilterOutProperty) - m_producer->get_int(
-                                          kFilterInProperty) + 1);
+        ui->durationSpinBox->setValue(m_producer->get_int(kFilterOutProperty)
+                                      - m_producer->get_int(kFilterInProperty) + 1);
     else
         ui->durationSpinBox->setValue(m_producer->get_playtime());
 }
@@ -171,10 +175,12 @@ void ImageProducerWidget::recreateProducer()
         }
     }
     Mlt::Producer *p = newProducer(MLT.profile());
-    p->pass_list(*m_producer, "force_aspect_ratio," kAspectRatioNumerator "," kAspectRatioDenominator
-                 ", begin, ttl," kShotcutResourceProperty ", autolength, length," kShotcutSequenceProperty ", "
-                 kPlaylistIndexProperty
-                 ", " kCommentProperty "," kOriginalResourceProperty "," kDisableProxyProperty "," kIsProxyProperty);
+    p->pass_list(*m_producer,
+                 "force_aspect_ratio," kAspectRatioNumerator "," kAspectRatioDenominator
+                 ", begin, ttl," kShotcutResourceProperty
+                 ", autolength, length," kShotcutSequenceProperty ", " kPlaylistIndexProperty
+                 ", " kCommentProperty "," kOriginalResourceProperty "," kDisableProxyProperty
+                 "," kIsProxyProperty);
     Mlt::Controller::copyFilters(*m_producer, *p);
     if (m_producer->get(kMultitrackItemProperty)) {
         emit producerChanged(p);
@@ -209,13 +215,15 @@ void ImageProducerWidget::on_resetButton_clicked()
 void ImageProducerWidget::on_aspectNumSpinBox_valueChanged(int)
 {
     if (m_producer) {
-        double new_sar = double(ui->aspectNumSpinBox->value()) /
-                         double(ui->aspectDenSpinBox->value());
+        double new_sar = double(ui->aspectNumSpinBox->value())
+                         / double(ui->aspectDenSpinBox->value());
         double sar = m_producer->get_double("aspect_ratio");
         if (m_producer->get("force_aspect_ratio") || new_sar != sar) {
             m_producer->set("force_aspect_ratio", QString::number(new_sar).toLatin1().constData());
-            m_producer->set(kAspectRatioNumerator, ui->aspectNumSpinBox->text().toLatin1().constData());
-            m_producer->set(kAspectRatioDenominator, ui->aspectDenSpinBox->text().toLatin1().constData());
+            m_producer->set(kAspectRatioNumerator,
+                            ui->aspectNumSpinBox->text().toLatin1().constData());
+            m_producer->set(kAspectRatioDenominator,
+                            ui->aspectDenSpinBox->text().toLatin1().constData());
         }
         emit producerChanged(producer());
     }
@@ -239,7 +247,7 @@ void ImageProducerWidget::on_sequenceCheckBox_clicked(bool checked)
 {
     QString resource = m_producer->get("resource");
     if (checked && m_producer->get_int(kIsProxyProperty)
-            && m_producer->get(kOriginalResourceProperty)) {
+        && m_producer->get(kOriginalResourceProperty)) {
         // proxy is not currently supported for image sequence, disable it
         resource = m_producer->get(kOriginalResourceProperty);
         m_producer->set(kDisableProxyProperty, 1);
@@ -260,7 +268,8 @@ void ImageProducerWidget::on_sequenceCheckBox_clicked(bool checked)
         int count = 0;
 
         // find the last numeric digit
-        for (; i && !name[i - 1].isDigit(); i--) {};
+        for (; i && !name[i - 1].isDigit(); i--) {
+        };
         // count the digits and build the begin value
         for (; i && name[i - 1].isDigit(); i--, count++)
             begin.prepend(name[i - 1]);
@@ -288,14 +297,15 @@ void ImageProducerWidget::on_sequenceCheckBox_clicked(bool checked)
                     imageCount++;
                     gap = 0;
                 } else {
-                    gap ++;
+                    gap++;
                 }
                 i++;
                 if (i % 100 == 0)
                     QCoreApplication::processEvents();
             }
-            m_producer->set("length", m_producer->frames_to_time(imageCount * m_producer->get_int("ttl"),
-                                                                 mlt_time_clock));
+            m_producer->set("length",
+                            m_producer->frames_to_time(imageCount * m_producer->get_int("ttl"),
+                                                       mlt_time_clock));
             ui->durationSpinBox->setValue(imageCount);
             ui->durationSpinBox->setEnabled(false);
             MAIN.showStatusMessage(tr("Reloading image sequence..."));
@@ -305,8 +315,10 @@ void ImageProducerWidget::on_sequenceCheckBox_clicked(bool checked)
         m_producer->Mlt::Properties::clear(kDisableProxyProperty);
         m_producer->Mlt::Properties::clear("begin");
         m_producer->set("resource", m_producer->get(kShotcutResourceProperty));
-        m_producer->set("length", m_producer->frames_to_time(qRound(MLT.profile().fps() *
-                                                                    Mlt::kMaxImageDurationSecs), mlt_time_clock));
+        m_producer->set("length",
+                        m_producer->frames_to_time(qRound(MLT.profile().fps()
+                                                          * Mlt::kMaxImageDurationSecs),
+                                                   mlt_time_clock));
         ui->durationSpinBox->setValue(qRound(MLT.profile().fps() * Settings.imageDuration()));
         ui->durationSpinBox->setEnabled(true);
     }
@@ -449,9 +461,10 @@ void ImageProducerWidget::on_actionDeleteProxy_triggered()
 void ImageProducerWidget::on_actionCopyHashCode_triggered()
 {
     qApp->clipboard()->setText(Util::getHash(*producer()));
-    QMessageBox::information(this, qApp->applicationName(),
-                             tr("The hash code below is already copied to your clipboard:\n\n") +
-                             Util::getHash(*producer()),
+    QMessageBox::information(this,
+                             qApp->applicationName(),
+                             tr("The hash code below is already copied to your clipboard:\n\n")
+                                 + Util::getHash(*producer()),
                              QMessageBox::Ok);
 }
 
